@@ -311,8 +311,11 @@ class Spot:
                 max_theta=self.surrogate_control["max_theta"],
                 n_theta=self.surrogate_control["n_theta"],
                 theta_init_zero=self.surrogate_control["theta_init_zero"],
+                p_val=self.surrogate_control["p_val"],
                 n_p=self.surrogate_control["n_p"],
                 optim_p=self.surrogate_control["optim_p"],
+                min_Lambda=self.surrogate_control["min_Lambda"],
+                max_Lambda=self.surrogate_control["max_Lambda"],
                 var_type=self.surrogate_control["var_type"],
                 spot_writer=self.spot_writer,
                 counter=self.design_control["init_size"] * self.design_control["repeats"] - 1,
